--- /dev/null	2012-08-08 12:42:09.000000000 +0000
+++ new/usr/src/uts/common/inet/dccp/dccp_features.c	2012-08-08 12:42:09.919532687 +0000
@@ -0,0 +1,99 @@
+/*
+ * This file and its contents are supplied under the terms of the
+ * Common Development and Distribution License ("CDDL"), version 1.0.
+ * You may only use this file in accordance with the terms of version
+ * 1.0 of the CDDL.
+ *
+ * A full copy of the text of the CDDL should have accompanied this
+ * source.  A copy of the CDDL is also available via the Internet at
+ * http://www.illumos.org/license/CDDL.
+ */
+
+/*
+ * Copyright 2012 David Hoeppner. All rights reserved.
+ */
+
+#include <sys/types.h> 
+#include <sys/stream.h> 
+#include <sys/debug.h> 
+#include <sys/cmn_err.h>
+#include <inet/dccp_impl.h>
+#include <inet/dccp_stack.h>
+
+/*
+ * This file contains functions to parse and process DCCP features.
+ */
+
+/*
+ * Feature handling.
+ */
+void
+dccp_parse_feature(dccp_t *dccp, uint8_t option, uint8_t length, uchar_t *up,
+    boolean_t mandatory)
+{
+	dccp_feature_t	*feature;
+	uint8_t		feature_type;
+	uint8_t		feature_length = length - 1;
+
+	cmn_err(CE_NOTE, "dccp_features.c: dccp_parse_feature");
+
+	feature_type = *up;
+
+	switch (feature_type) {
+	case DCCP_FEATURE_CCID:
+		cmn_err(CE_NOTE, "DCCP_FEATURE_CCID");
+		break;
+	case DCCP_FEATURE_ALLOW_SHORT_SEQNOS:
+		cmn_err(CE_NOTE, "DCCP_FEATURE_ALLOW_SHORT_SEQNOS");
+		break;
+	case DCCP_FEATURE_SEQUENCE_WINDOW:
+		cmn_err(CE_NOTE, "DCCP_FEATURE_SEQUENCE_WINDOW");
+		break;
+	case DCCP_FEATURE_ECN_INCAPABLE:
+		cmn_err(CE_NOTE, "DCCP_FEATURE_ECN_INCAPABLE");
+		break;
+	case DCCP_FEATURE_ACK_RATIO:
+		cmn_err(CE_NOTE, "DCCP_FEATURE_ACK_RATIO");
+		break;
+	case DCCP_FEATURE_SEND_ACK_VECTOR:
+		cmn_err(CE_NOTE, "DCCP_FEATURE_SEND_ACK_VECTOR");
+		break;
+	case DCCP_FEATURE_SEND_NDP_COUNT:
+		cmn_err(CE_NOTE, "DCCP_FEATURE_SEND_NDP_COUNT");
+		break;
+	case DCCP_FEATURE_MIN_CHECKSUM_COVERAGE:
+		cmn_err(CE_NOTE, "DCCP_FEATURE_MIN_CHECKSUM_COVERAGE");
+		break;
+	case DCCP_FEATURE_CHECK_DATA_CHECKSUM:
+		cmn_err(CE_NOTE, "DCCP_FEATURE_CHECK_DATA_CHECKSUM");
+		break;
+
+	default:
+		cmn_err(CE_NOTE, "ERROR DEFAULT");
+		break;
+	}
+
+	cmn_err(CE_NOTE, "feature len: %d", feature_length);
+
+	feature = (dccp_feature_t *)kmem_alloc(sizeof (dccp_feature_t),
+	    KM_SLEEP);
+	if (feature == NULL) {
+		return;
+	}
+
+	feature->df_option = option;
+	feature->df_type = feature_type;
+	feature->df_mandatory = mandatory;
+
+	list_insert_tail(&dccp->dccp_features, feature);
+}
+
+void
+dccp_features_init(void)
+{
+}
+
+void
+dccp_features_destroy(void)
+{
+}
